import { Message } from 'element-ui';
//将base64码转化为file（Blob）
//此处函数对压缩后的base64经过处理返回{size: "", type: ""} 
function convertBase64UrlToBlob(urlData){
    var arr = urlData.split(','), mime = arr[0].match(/:(.*?);/)[1],
        bstr = atob(arr[1]), n = bstr.length, u8arr = new Uint8Array(n);
    while(n--){
        u8arr[n] = bstr.charCodeAt(n);
    }
    return new Blob([u8arr], {type:mime});
}

function closeLoading($loading){
    $loading&&$loading.close()
}
export function imgCompress(file, $loading) {
    //判断是否为图片文件
    return new Promise(
        function(resolve, reject){
            if (file.type.indexOf('image') == -1) {
                Message({
                    message: '请选择图片',
                    type: 'warning'
                })
                closeLoading($loading)
                reject("-1")
            } else {
                let reader = new FileReader();
                let image = new Image();
                reader.readAsDataURL(file);
                reader.onload = function () {
                    file.src = this.result;
                    image.onload = function(){
                        let width = image.width;
                        let height = image.height;
                        file.width = width;
                        file.height = height;
                    };
                    image.onerror = function(){
                        Message({
                            message: '图片加载失败',
                            type: 'error'
                        })
                        closeLoading($loading)
                        reject(-2)
                    }
                    image.src= file.src; //页面上显示所选择的图片
                    if(file.size/1024 > 1025){//判断图片的大小，超过1M 进行压缩
                        compress(file, {quality: 0.2})
                        .then(function(v){
                            file = new File([v], file.name)
                            resolve(file)
                        })
                        .catch(function(data){
                            closeLoading($loading)
                            reject(data)
                        })
                    } else {
                        resolve(file)
                    }
                }
            }
        }
    )
}

function compress(path, obj){//path是指上传的图片，obj是压缩的品质，越低越模糊
    return new Promise(function(resolve, reject){
        var img = new Image();
        img.src = path.src;
        img.onload = function(){
            var that = this;  //这里的this 是把img的对象指向改变为that 
            // 默认按比例压缩
            var w = that.width,
                h = that.height,
                scale = w / h;
            w = obj.width || w;
            h = obj.height || (w / scale);
            var quality = 0.7;  // 默认图片质量为0.7
            //生成canvas
            var canvas = document.createElement('canvas');
            var ctx = canvas.getContext('2d');
            // 创建属性节点
            var anw = document.createAttribute("width");
            anw.nodeValue = w;
            var anh = document.createAttribute("height");
            anh.nodeValue = h;
            canvas.setAttributeNode(anw);
            canvas.setAttributeNode(anh);
            ctx.fillStyle = "#fff";
            ctx.fillRect(0, 0, canvas.width, canvas.height);
            ctx.drawImage(that, 0, 0, w, h);
            // 图像质量
            if(obj.quality && obj.quality <= 1 && obj.quality > 0){
                quality = obj.quality;
            }
            // quality值越小，所绘制出的图像越模糊
            var base64 = canvas.toDataURL('image/jpeg', quality);
            // 回调函数返回base64的值
            var urlFile = convertBase64UrlToBlob(base64) //这个地方的处理是为了把压缩的base64转化为对象，获得压缩后图片的大小size，方便对压缩后的图片再次进行判断；
            resolve(urlFile) 
        }
        img.onerror = function(){
            Message({
                message: '图片加载失败',
                type: 'error'
            })
            reject(-2)
        }
    })
}